@@ -1,6 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2003 by Hideki Ikemoto                                  *
- *   ikemo@wakaba.jp                                                       *
+ *   ikemo@users.sourceforge.jp                                            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -24,10 +24,15 @@
 #include <klistview.h>
 #include <kiconloader.h>
 #include <klocale.h>
- 
+#include <kpopupmenu.h>
+#include <krun.h>
+
 #include "kitasubjectview.h"
+#include "favoritelistview.h"
 #include "kita.h"
 #include "kitacacheinfo.h"
+#include "part/kita2ch.h"
+#include "libkita/thread.h"
 
 enum SubjectViewRows {
   Row_ID,
@@ -35,7 +40,9 @@ enum SubjectViewRows {
   Row_Subject,
   Row_ResNum,
   Row_Vested,
+  Row_Unread,
   Row_DatName,
+  Row_DatURL
 };
 
 KitaSubjectView::KitaSubjectView(QWidget *parent, const char *name)
@@ -45,22 +52,29 @@ KitaSubjectView::KitaSubjectView(QWidget *parent, const char *name)
     SearchButton->setPixmap( SmallIcon("find") );
     HideButton->setPixmap( SmallIcon("filter") );
   }
-  
+
   subjectList->addColumn(i18n("No."));
   subjectList->addColumn("");
   subjectList->addColumn(i18n("Title"));
   subjectList->addColumn(i18n("ResNum"));
   subjectList->addColumn(i18n("Vested"));
+  subjectList->addColumn(i18n("Unread"));
   subjectList->addColumn(i18n("Dat"));
 
   subjectList->setColumnWidth(Row_Subject, 400);
   subjectList->setColumnWidthMode(Row_Subject, QListView::Manual);
 
-  connect(subjectList, SIGNAL(clicked(QListViewItem*)), SLOT(loadThread(QListViewItem*)));
   connect( SearchButton, SIGNAL( clicked() ), SLOT( slotSearchButton() ) );
   connect( SearchCombo, SIGNAL( activated(int) ), SLOT( slotSearchButton() ) );
   connect(this, SIGNAL(signalSubjectListClicked(QListViewItem*)), subjectList, SIGNAL(clicked(QListViewItem*)));
   connect( HideButton, SIGNAL( toggled(bool) ), SLOT( slotHideButton(bool) ) );
+  connect( m_subjectTab, SIGNAL( currentChanged(QWidget*) ), SLOT( slotCurrentChanged(QWidget*) ) );
+  connect( m_favoriteListView, SIGNAL( signalShowThread( const Kita::Thread& ) ),
+                               SIGNAL( signalShowThread( const Kita::Thread& ) ) );
+  connect( subjectList, SIGNAL( contextMenuRequested( QListViewItem*, const QPoint&, int ) ),
+                        SLOT( slotContextMenuRequested( QListViewItem*, const QPoint&, int ) ) );
+  connect( subjectList, SIGNAL( mouseButtonClicked( int, QListViewItem*, const QPoint&, int ) ),
+                        SLOT( loadThread( int, QListViewItem* ) ) );
 }
 
 KitaSubjectView::~KitaSubjectView()
@@ -71,15 +85,22 @@ void KitaSubjectView::reloadSubject()
 {
 }
 
-void KitaSubjectView::loadThread(QListViewItem* item)
+void KitaSubjectView::loadThread( int, QListViewItem* item )
 {
+  if( ! item ) return;
+
   QString datName = item->text(Row_DatName);
-  KURL datURL = m_boardURL;
+  KURL datURL = m_board.url();
   datURL.addPath("/dat/" + datName);
-  emit signalShowThread(datURL, m_boardURL, m_boardName);
+
+  Kita::Thread thread( m_board, datURL );
+  thread.setName( item->text( Row_Subject ) );
+  thread.setResNum( item->text( Row_Vested ).toInt() );
+
+  emit signalShowThread( thread );
 }
 
-void KitaSubjectView::slotLoadBoard(const KURL& url, const QString& boardName)
+void KitaSubjectView::loadBoard(const Kita::Board& board)
 {
   // reset member variables.
   {
@@ -88,57 +109,37 @@ void KitaSubjectView::slotLoadBoard(const KURL& url, const QString& boardName)
     m_prevquery = "";
   }
 
-  m_boardURL = url;
-  m_boardName = boardName;
+  m_board = board;
 
-  KIO::SlaveConfig::self()->setConfigData("http", url.host() , "UserAgent", "Monazilla/1.00 (Kita/0.21)");
+  KitaCacheInfo* cache = KitaCacheInfo::getInstance();
+  m_threadList = m_board.getThreadList();
 
-  QString tmpFile;
-  KURL subjectURL = KURL(url, "subject.txt");
-  if(KIO::NetAccess::download(subjectURL, tmpFile)) {
-    QIODevice* tmpDevice = KFilterDev::deviceForFile(tmpFile, "application/x-gzip");
-    tmpDevice->open(IO_ReadOnly);
+  // clear list
+  subjectList->clear();
 
-    QTextStream stream(tmpDevice);
-    stream.setCodec(QTextCodec::codecForName("Shift_JIS"));
+  for(unsigned i=0; i<m_threadList.count(); i++) {
+    Kita::Thread* thread = m_threadList.at(i);
 
-    // clear list
-    subjectList->clear();
-
-    // parse subject.txt(only one format...)
-    QRegExp regexp("(\\d+\\.dat)<>(.*)\\((\\d+)\\)");
-    QString line;
-    int row=1;
-
-    KitaCacheInfo* cache = KitaCacheInfo::getInstance();
-
-    while((line = stream.readLine()) != QString::null) {
-      int pos = regexp.search(line);
-      if(pos != -1) {
-        QString fname = regexp.cap(1);
-        QString subject = regexp.cap(2);
-        QString num = regexp.cap(3);
-
-        KURL datURL = m_boardURL;
-        datURL.addPath("/dat/" + fname);
-        int vested = cache->getVestedNum(datURL);
-        new KListViewItem(subjectList,
-                          QString("%1").arg(row, 4),
-                          "",
-                          subject,
-                          QString("%1").arg(num, 4),
-                          vested > 0 ? QString::number(vested) : "",
-                          fname);
-        row++;
-      }
-    }
-
-    KIO::NetAccess::removeTempFile(tmpFile);
+    int vested = cache->getVestedNum(thread->datURL());
+    new KListViewItem(subjectList,
+                      QString("%1").arg(i+1, 4),
+                      "",
+                      thread->name(),
+                      QString("%1").arg(thread->resNum(), 4),
+                      (vested > 0) ? QString::number(vested) : QString(""),
+                      (vested > 0 && thread->resNum() != vested) ? QString::number(thread->resNum() - vested) : QString(""),
+                      thread->datURL().fileName(),
+                      thread->datURL().prettyURL());
   }
 
+  // set tab label
+  // XXX
+  m_subjectTab->setTabLabel( m_subjectTab->page( 0 ), m_board.name() );
+
   if( HideButton->isOn() ) {
     HideButton->toggle();
   }
+  emit loadBoardCompleted(m_board.url());
 }
 
 void KitaSubjectView::slotSearchButton()
@@ -230,3 +231,52 @@ void KitaSubjectView::slotHideButton(bool on)
     ++listIt;
   }
 }
+
+void KitaSubjectView::setFont( const QFont& font )
+{
+  subjectList->setFont(font);
+}
+
+void KitaSubjectView::updateThread(const Kita::Thread& updated_thread)
+{
+  for(QListViewItem* item = subjectList->firstChild(); item; item = item->nextSibling() ) {
+    if( item->text(Row_DatURL) == updated_thread.datURL().prettyURL() ) {
+      int resNum = item->text( Row_ResNum ).toInt();
+      int vested = updated_thread.resNum();
+      item->setText( Row_Vested, QString::number( vested ) );
+      item->setText( Row_Unread, vested > 0 && resNum != vested ? QString::number(resNum - vested) : QString(""));
+    }
+  }
+}
+
+void KitaSubjectView::slotCurrentChanged(QWidget* widget)
+{
+  if( QString::compare(widget->name(), "favoriteTab") == 0 ) {
+    m_favoriteListView->update();
+  }
+}
+
+void KitaSubjectView::slotContextMenuRequested( QListViewItem* item, const QPoint& point, int )
+{
+  if( item == 0 ) {
+    return;
+  }
+
+  KPopupMenu popup( 0 );
+  popup.insertItem( i18n("Open with Web Browser"), 0 );
+
+  QString datName = item->text(Row_DatName);
+  KURL datURL = m_board.url();
+  datURL.addPath("/dat/" + datName);
+
+  Kita::Thread thread( m_board, datURL );
+
+  switch( popup.exec( point ) ) {
+  case 0:
+    KRun::runURL( thread.url(), "text/html" );
+    break;
+  default:
+    break;
+  }
+}
+
