@@ -1,6 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2003 by Hideki Ikemoto                                  *
- *   ikemo@wakaba.jp                                                       *
+ *   ikemo@users.sourceforge.jp                                            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -14,12 +14,13 @@
 #include <qwidget.h>
 #include <kurl.h>
 #include "kitasubjectviewbase.h"
+#include "part/kita2ch.h"
+#include "libkita/board.h"
 
-class Kita;
 class KListViewItem;
 
 /**
- * 
+ *
  * Hideki Ikemoto
  **/
 class KitaSubjectView : public KitaSubjectViewBase
@@ -32,17 +33,19 @@ public:
 
 public slots:
   void reloadSubject();
-  void loadThread(QListViewItem* item);
-  void slotLoadBoard(const KURL& url, const QString& boardName);
-  void slotHideButton(bool on);
+  void loadBoard( const Kita::Board& board );
+  void setFont( const QFont& font );
+  void updateThread( const Kita::Thread& thread );
+private slots:
+  void loadThread( int, QListViewItem* item );
 
 private: // Private attributes
-  KURL m_boardURL;
-  QString m_boardName;
+  QPtrList<Kita::Thread> m_threadList;
+  Kita::Board m_board;
   QStringList m_prevquery;
-  int m_nextHitIndex;
+  unsigned m_nextHitIndex;
   QValueList<KListViewItem*> m_hitList;
-  
+
   void insertSearchCombo();
   QStringList parseSearchQuery(const QString &input);
   void searchNext(const QStringList &input);
@@ -50,9 +53,13 @@ private: // Private attributes
 
 private slots:
   void slotSearchButton();
+  void slotCurrentChanged(QWidget* widget);
+  void slotHideButton(bool on);
+  void slotContextMenuRequested( QListViewItem*, const QPoint&, int );
 
 signals:
-  void signalShowThread(const KURL& datURL, const KURL& boardURL, const QString& boardName);
+  void loadBoardCompleted(const KURL&);
+  void signalShowThread( const Kita::Thread& thread );
   void signalSubjectListClicked(QListViewItem* item);
 };
 
