@@ -35,11 +35,7 @@ Board::~Board()
 
 const KURL Board::subjectTxtURL() const
 {
-  if( m_boardURL.isEmpty() ) {
-    return KURL();
-  } else {
-    return KURL(m_boardURL, "./subject.txt");
-  }
+  return KURL(m_boardURL, "./subject.txt");
 }
 
 const KURL& Board::url() const
@@ -59,13 +55,9 @@ const QString Board::id() const
 
 const QPtrList<Thread> Board::getThreadList() const
 {
-  if( m_boardURL.isEmpty() ) {
-    qDebug("Waring: board url is empty!");
-    return QPtrList<Thread>();
-  }
   QPtrList<Thread> threadList;
 
-  KIO::SlaveConfig::self()->setConfigData("http", m_boardURL.host() , "UserAgent", "Monazilla/1.00 (Kita/0.6)");
+  KIO::SlaveConfig::self()->setConfigData("http", m_boardURL.host() , "UserAgent", "Monazilla/1.00 (Kita/0.51)");
   QString tmpFile;
   if(KIO::NetAccess::download(subjectTxtURL(), tmpFile)) {
     QIODevice* tmpDevice = KFilterDev::deviceForFile(tmpFile, "application/x-gzip");
