@@ -28,25 +28,19 @@ FavoriteThreads* FavoriteThreads::getInstance()
   return instance;
 }
 
-void FavoriteThreads::insert( const Kita::Thread* thread )
+void FavoriteThreads::insert( const Kita::Thread& thread )
 {
-  if( ! m_threadDict.find( thread->datURL().prettyURL() ) ) {
-    m_threadDict.insert(thread->datURL().prettyURL(), thread);
-  }
+  m_threadMap.insert(thread.datURL().prettyURL(), thread);
 }
 
 void FavoriteThreads::remove( const QString& datURL )
 {
-  m_threadDict.remove( datURL );
+  m_threadMap.remove( datURL );
 }
 
 bool FavoriteThreads::contains( const QString& datURL ) const
 {
-  if( m_threadDict.find( datURL ) ) {
-    return true;
-  } else {
-    return false;
-  }
+  return m_threadMap.contains( datURL );
 }
 
 FavoriteThreads* FavoriteThreads::fromXml( const QString& xml )
@@ -63,9 +57,9 @@ FavoriteThreads* FavoriteThreads::fromXml( const QString& xml )
   if( parser.isValid() ) {
     QPtrList<Kita::Thread> threads = parser.getThreads();
 
-    instance->m_threadDict.clear();
+    instance->m_threadMap.clear();
     for( Kita::Thread* thread = threads.first(); thread; thread = threads.next() ) {
-      instance->insert( thread );
+      instance->insert( Kita::Thread( *(thread->getBoard()), thread->datURL(), thread->name(), thread->resNum() ) );
     }
   } else {
     qDebug("inValid");
@@ -80,10 +74,9 @@ const QString FavoriteThreads::toXml() const
 
   ret += "<favorites xmlns=\"http://kita.sourceforge.jp/ns/favorites\">\n";
 
-//  FavoriteThreads::const_iterator it;
-  QDictIterator<Kita::Thread> it( threads() );
-  for( ; it.current(); ++it ) {
-    ret += it.current()->toXmlFragment();
+  FavoriteThreads::const_iterator it;
+  for( it = threads().begin(); it != threads().end(); ++it ) {
+    ret += (*it).toXmlFragment();
   }
   ret += "</favorites>\n";
 
@@ -114,11 +107,11 @@ bool FavoriteThreads::test()
                 "</favorites>\n";
 
   FavoriteThreads* favorites = FavoriteThreads::fromXml( xml );
-  QDict<Kita::Thread> threads = favorites->threads();
+  QMap<QString, Kita::Thread> threads = favorites->threads();
 
   if( threads.size() != 2 ) qDebug("inValid: line=%d", __LINE__);
-  if( favorites->contains( "http://pc.2ch.net/linux/dat/1022744633.dat" ) != true ) qDebug("inValid: line=%d", __LINE__);
-  if( favorites->contains( "http://pc.2ch.net/unix/dat/956134538.dat" ) != true ) qDebug("inValid: line=%d", __LINE__);
+  if( threads.contains( "http://pc.2ch.net/linux/dat/1022744633.dat" ) != true ) qDebug("inValid: line=%d", __LINE__);
+  if( threads.contains( "http://pc.2ch.net/unix/dat/956134538.dat" ) != true ) qDebug("inValid: line=%d", __LINE__);
   return true;
 }
 
