@@ -23,8 +23,6 @@
 
 using namespace Kita;
 
-ThreadFactory* ThreadFactory::instance = 0;
-
 Thread::Thread() : m_board( 0 )
 {
 }
@@ -273,7 +271,7 @@ QString ThreadAccess::get()
 {
   if ( m_thread.datURL().protocol() != "k2ch" ) {
     KIO::SlaveConfig::self()->setConfigData("http", m_thread.datURL().host() ,
-                                          "UserAgent", "Monazilla/1.00 (Kita/0.6)");
+                                          "UserAgent", "Monazilla/1.00 (Kita/0.51)");
   }
 
   KIO::TransferJob* job = KIO::get(m_thread.datURL(), true, true);
@@ -338,23 +336,4 @@ void ThreadAccess::killJob()
   if( m_currentJob ) m_currentJob->kill();
 }
 
-void ThreadFactory::insertThread( Thread& thread )
-{
-  if( ! instance ) {
-    instance = new ThreadFactory();
-  }
-
-  Thread* new_thread = new Thread( thread.getBoard(), thread.datURL(), thread.name(), thread.resNum() );
-  instance->m_dict.insert( thread.datURL().url(), new_thread );
-}
-
-Thread* ThreadFactory::getThread( QString& datURL )
-{
-  if( ! instance ) {
-    instance = new ThreadFactory();
-  }
-
-  return instance->m_dict[ datURL ];
-}
-
 #include "thread.moc"
